@@ -3,7 +3,7 @@
 #
 # Univention Mail Dovecot - shared code for listeners
 #
-# Copyright 2015-2021 Univention GmbH
+# Copyright 2015-2022 Univention GmbH
 #
 # https://www.univention.de/
 #
@@ -40,7 +40,7 @@ import imaplib
 import shutil
 import tempfile
 try:
-	from typing import Any, Dict, List, Optional, Tuple  # noqa F401
+	from typing import Any, Dict, List, Optional, Tuple  # noqa: F401
 except ImportError:
 	pass
 
